@@ -19,6 +19,7 @@ import validators
 from urllib.parse import urljoin
 from urllib.parse import urlsplit
 from aiohttp import ClientSession
+import async_timeout
 
 
 
@@ -106,7 +107,7 @@ async def fetch(client,url):
         return await resp.text()
 
 #############################VIPER API CALLS ################    
-async def tcp_echo_clientviper(message, loop,host,port,microserviceid,timeout=0):
+async def tcp_echo_clientviper(message, loop,host,port,microserviceid,timeout=180):
 
     hostarr=host.split(":")
     hbuf=hostarr[0]
@@ -123,7 +124,8 @@ async def tcp_echo_clientviper(message, loop,host,port,microserviceid,timeout=0)
     geturl=formaturlviper(message,host,microserviceid,hbuf,port) #host contains http:// or https://
     message="%s" % geturl 
 
-    async with ClientSession(timeout=timeout) as session:
+    with async_timeout.timeout(timeout):
+      async with ClientSession() as session:
         html = await fetch(session,message)
         return html
 
